Actions, Resources, and Condition Keys for Amazon Elastic Container Service for Kubernetes - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Elastic Container Service for Kubernetes.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

# Actions, Resources, and Condition Keys for Amazon Elastic Container Service for Kubernetes

Amazon Elastic Container Service for Kubernetes (service prefix: `eks`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon Elastic Container Service for Kubernetes
- Resources Defined by Amazon Elastic Container Service for Kubernetes
- Condition Keys for Amazon Elastic Container Service for Kubernetes

## Actions Defined by Amazon Elastic Container Service for Kubernetes

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CreateCluster | Creates an Amazon EKS cluster. | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateNodegroup | Creates an Amazon EKS Nodegroup. | Write | cluster* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteCluster | Deletes an Amazon EKS cluster. | Write | cluster* |  |
DeleteNodegroup | Deletes an Amazon EKS Nodegroup. | Write | nodegroup* |  |
DescribeCluster | Returns descriptive information about an Amazon EKS cluster. | Read | cluster* |  |
DescribeNodegroup | Returns descriptive information about an Amazon EKS nodegroup. | Read | nodegroup* |  |
DescribeUpdate | Describes a given update for a given Amazon EKS cluster/nodegroup (in the specified or default region). | Read | cluster* |  |
nodegroup |  |
ListClusters | Lists the Amazon EKS clusters in your AWS account (in the specified or default region). | List |  |  |
ListNodegroups | Lists the Amazon EKS nodegroups in your AWS account (in the specified or default region) attached to given cluster. | List | cluster* |  |
ListTagsForResource | List tags for the specified resource. | List | cluster |  |
nodegroup |  |
ListUpdates | Lists the updates for a given Amazon EKS cluster/nodegroup (in the specified or default region). | List | cluster* |  |
nodegroup |  |
TagResource | Tags the specified resource. | Tagging | cluster |  |
nodegroup |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Untags the specified resource. | Tagging | cluster |  |
nodegroup |  |
| aws:TagKeys |
UpdateClusterConfig | Update Amazon EKS cluster configurations (eg: API server endpoint access). | Write | cluster* |  |
UpdateClusterVersion | Update the Kubernetes version of an Amazon EKS cluster. | Write | cluster* |  |
UpdateNodegroupConfig | Update Amazon EKS nodegroup configurations (eg: min/max/desired capacity or labels). | Write | nodegroup* |  |
UpdateNodegroupVersion | Update the Kubernetes version of an Amazon EKS nodegroup. | Write | nodegroup* |  |

## Resources Defined by Amazon Elastic Container Service for Kubernetes

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table.

Resource Types | ARN | Condition Keys
--- | --- | ---
cluster | `arn:${Partition}:eks:${Region}:${Account}:cluster/${ClusterName}` | aws:ResourceTag/${TagKey}
nodegroup | `arn:${Partition}:eks:${Region}:${Account}:nodegroup/${ClusterName}/${NodegroupName}/${UUID}` | aws:ResourceTag/${TagKey}

## Condition Keys for Amazon Elastic Container Service for Kubernetes

Amazon Elastic Container Service for Kubernetes defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table.

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference.

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by a key that is present in the request the user makes to the EKS service. | String
aws:ResourceTag/${TagKey} | Filters access by a tag key and value pair. | String
aws:TagKeys | Filters access by the list of all the tag key names present in the request the user makes to the EKS service. | String

On this page:

- Actions Defined by Amazon Elastic Container Service for Kubernetes
- Resources Defined by Amazon Elastic Container Service for Kubernetes
- Condition Keys for Amazon Elastic Container Service for Kubernetes

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more